@@ -29,12 +29,13 @@ import testtools
 
 import novaclient
 import novaclient.api_versions
+from novaclient import base
 import novaclient.client
 from novaclient.v2 import networks
 import novaclient.v2.shell
 
 BOOT_IS_COMPLETE = ("login as 'cirros' user. default password: "
-                    "'cubswin:)'. use 'sudo' for root.")
+                    "'gocubsgo'. use 'sudo' for root.")
 
 
 def is_keystone_version_available(session, version):
@@ -371,7 +372,7 @@ class ClientTestBase(testtools.TestCase):
                     raise
             time.sleep(poll_interval)
         else:
-            self.fail("The resource '%s' still exists." % resource.id)
+            self.fail("The resource '%s' still exists." % base.getid(resource))
 
     def name_generate(self):
         """Generate randomized name for some entity."""
